@@ -1,5 +1,8 @@
 #
-# English resource of amazon plugin $Revision: 1.5.2.1 $
+# English resource of amazon plugin $Revision: 1.5.2.4 $
+#
+# Copyright (C) 2002 HAL99 <hal99@mtj.biglobe.ne.jp>
+# You can redistribute it and/or modify it under GPL2.
 #
 
 #
@@ -25,19 +28,25 @@
 #   @options['amazon.aid']: Your Amazon Assosiate ID. This option can be
 #                           changed in preferences page.
 #   @options['amazon.hideconf']: When you want to prohibit changing amazon.aid
-#                                via preferences page, set false.
+#                             via preferences page, set false.
 #   @options['amazon.proxy']: HTTP proxy in "host:post" style.
 #   @options['amazon.imgsize']: specify image size (0:laege, 1:regular, 2:small)
 #   @options['amazon.hidename']: hide book name when class="amazon", set true.
+#   @options['amazon.default_image_base']: URL that include default images.
+#                             amazon.rb uses images on tDiary.org when this
+#                             option not specified. If you want to use your
+#                             original images, modify PNG file in amazon directory.
 #   @options['amazon.nodefault']: If you dosen't want to show default image 
-#                                 when the book image not found, set true.
-#
+#                             when the book image not found, set true.
+
 
 @amazon_url = 'http://www.amazon.com/exec/obidos/ASIN'
+@amazon_ecs_url = 'http://webservices.amazon.com/onca/xml'
 @amazon_item_name = /^Amazon\.com: (.*)$/
 @amazon_item_image = %r|(<img src="(http://images\.amazon\.com/images/P/(.*MZZZZZZZ_?.jpg))".*?>)|i
 @amazon_label_conf = 'Amazon'
 @amazon_label_aid = 'Amazon Assosiate ID'
+@amazon_label_aid_desc = "If you don't specified it, this plugin call amazon with ID of tDiary developer."
 @amazon_label_imgsize = 'Image size of the book'
 @amazon_label_large = 'Large'
 @amazon_label_regular = 'Regular'
@@ -50,5 +59,5 @@
 @amazon_label_usedefault = 'Use default image'
 @amazon_label_clearcache = 'Clear Cache'
 @amazon_label_clearcache_desc = 'Delete local cache file about book images'
-@amazon_label_over18 = 'Images of adult materials'
-@amazon_label_over18_desc = 'Fetch images of adult materials.'
+
+@amazon_encoder = Proc::new {|s| s }
